"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProjectInitCommand = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const config_1 = require("../../lib/config");
const path = tslib_1.__importStar(require("path"));
const stack_factory_1 = require("../../lib/stack-factory");
class ProjectInitCommand extends core_1.Command {
    async run() {
        const { args } = await this.parse();
        const projectDir = this.getProjectPath(args.projectDir);
        await this.execute(projectDir);
    }
    async execute(projectDir) {
        const projectPath = path.join(projectDir, config_1.PROJECT_FILE_NAME);
        if ((0, config_1.fileExists)(projectPath)) {
            this.error(`Project already exists at ${projectPath}`);
        }
        this.log(`Creating project at ${projectPath}`);
        const existingProject = (0, config_1.getProjectConfigPath)(projectPath);
        if (existingProject !== undefined) {
            this.log(`Warning: the new project will override the existing project at ${existingProject}`);
        }
        const shellConfig = config_1.ShellConfig.readWithOverrides({
            projectPath: projectPath,
            projectConfig: config_1.ProjectConfig.emptyConfig(),
        });
        const stackFactory = new stack_factory_1.StackFactory(this, shellConfig);
        await stackFactory.addStack({
            default: true,
        });
    }
    getProjectPath(projectDir) {
        if (projectDir) {
            if (path.isAbsolute(projectDir)) {
                return projectDir;
            }
            else {
                return path.join(process.cwd(), projectDir);
            }
        }
        else {
            return process.cwd();
        }
    }
}
exports.ProjectInitCommand = ProjectInitCommand;
ProjectInitCommand.args = {
    projectDir: core_1.Args.string({
        name: "projectDir",
        required: false,
        description: "The directory to initialize as a fauna project.  If not provided will default to the current directory.",
    }),
};
ProjectInitCommand.description = "Initialize a project directory by generating a .fauna-project file.";
ProjectInitCommand.examples = [
    "$ fauna project init",
    "$ fauna project init path/to/some/other/dir",
];
