"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Stack = exports.ProjectConfig = void 0;
const tslib_1 = require("tslib");
const ini = require("ini");
const fs = tslib_1.__importStar(require("fs"));
const _1 = require(".");
// Represents `.fauna-project`
class ProjectConfig {
    /**
     * This method is used to obtain an empty project config when fauna project init is used.
     */
    static emptyConfig() {
        return new ProjectConfig({});
    }
    constructor(stacks, defaultStack) {
        this.stacks = stacks;
        this.defaultStack = defaultStack;
    }
    static fromConfig(config) {
        const defaultStack = config.strOpt("default");
        const stacks = config.objectExists("stack")
            ? Object.fromEntries(config.objectsIn("stack").map(([k, v]) => [k, new Stack(v)]))
            : {};
        if (defaultStack && stacks[defaultStack] === undefined) {
            throw new _1.InvalidConfigError(`Default stack '${defaultStack}' was not found`);
        }
        return new ProjectConfig(stacks, defaultStack);
    }
    validate(rootConfig) {
        for (const stack of Object.values(this.stacks)) {
            if (rootConfig.endpoints[stack.endpoint] === undefined) {
                throw new _1.InvalidConfigError(`Endpoint '${stack.endpoint}' not found in ~/.fauna-shell`);
            }
        }
    }
    save(path) {
        const config = {
            default: this.defaultStack,
            stack: this.stacks,
        };
        const encoded = ini.encode(config);
        fs.writeFileSync(path, encoded);
    }
}
exports.ProjectConfig = ProjectConfig;
class Stack {
    constructor(config) {
        this.endpoint = config.str("endpoint");
        this.database = config.str("database");
    }
}
exports.Stack = Stack;
